@@ -1,7 +1,4 @@
 package App::perlmv;
-{
-  $App::perlmv::VERSION = '0.43';
-}
 # ABSTRACT: Rename files using Perl code
 
 use 5.010;
@@ -15,6 +12,7 @@ use File::Path qw(make_path);
 use File::Spec;
 use Getopt::Long qw(:config no_ignore_case bundling);
 
+our $VERSION = '0.44'; # VERSION
 
 sub new {
     my ($class) = @_;
@@ -39,7 +37,7 @@ sub new {
         codes           => [],
         dry_run         => 0,
         homedir         => $homedir,
-        sort_mode       => 1, # 1 = sort ascibetically, -1 = reverse, 0 = no sort
+        sort_mode       => 1, # 1=sort ascibetically, -1=reverse, 0=no sort
         overwrite       => 0,
         process_dir     => 1,
         process_symlink => 1,
@@ -100,9 +98,10 @@ sub run {
 
     # -m is reserved for file mode
     my $default_mode =
-        $0 =~ /perlcp/   ? 'copy'    :
-        $0 =~ /perlln_s/ ? 'symlink' :
-        $0 =~ /perlln/   ? 'link'    :
+        $0 =~ /perlcp/     ? 'copy'    :
+        $0 =~ /perlln_s/   ? 'symlink' :
+        $0 =~ /perlln/     ? 'link'    :
+        $0 =~ /perlmv/     ? 'move'    :
         'rename';
 
     $self->{'dry_run'} and $self->{'verbose'}++;
@@ -198,14 +197,15 @@ Options:
  -f  (--files) Only process files, do not process directories
  -h  (--help) Show this help
  -l  (--list) list all scriptlets
- -M <MODE> (--mode) Specify mode, default is 'rename' (or 'r'). Use 'copy' or 'c'
-     to copy instead of rename, 'symlink' or 's' to create a symbolic link, and
+ -M <MODE> (--mode) Specify mode, default is 'mv' (or 'm'). Use 'rename' or 'r'
+     for rename (the same as mv but won't do cross devices), 'copy' or 'c' to
+     copy instead of rename, 'symlink' or 's' to create a symbolic link, and
      'link' or 'l' to create a (hard) link.
  -o  (--overwrite) Overwrite (by default, ".1", ".2", and so on will be appended
      to avoid overwriting existing files)
  -p  (--parents) Create intermediate directories
  -R  (--recursive) Recursive
- -r  (--reverse) reverse order of processing (by default order is asciibetically)
+ -r  (--reverse) reverse order of processing (by default asciibetically)
  -S  (--no-symlinks) Do not process symlinks
  -s <NAME> (--show) Show source code for scriptlet
  -T  (--no-sort) do not sort files (default is sort ascibetically)
@@ -430,7 +430,9 @@ sub process_item {
     my $action;
     if (!defined($self->{mode}) || $self->{mode} =~ /^(rename|r)$/) {
         $action = "rename";
-    } elsif ($self->{mode} =~ /^(copy|c)$/) {
+    } elsif ($self->{mode} =~ /^(move|mv|m)$/) {
+        $action = "move";
+    } elsif ($self->{mode} =~ /^(copy|cp|c)$/) {
         $action = "copy";
     } elsif ($self->{mode} =~ /^(symlink|sym|s)$/) {
         $action = "symlink";
@@ -438,7 +440,7 @@ sub process_item {
         $action = "link";
     } else {
         die "Unknown mode $self->{mode}, please use one of: ".
-            "rename (r), copy (c), symlink (s), or link (l).";
+            "move (m), rename (r), copy (c), symlink (s), or link (l).";
     }
 
     my $orig_new = $new;
@@ -455,7 +457,7 @@ sub process_item {
         }
     }
     $self->{_exists}{$anew}++;
-    delete $self->{_exists}{$aold} if $action eq 'rename';
+    delete $self->{_exists}{$aold} if $action eq 'rename' || $action eq 'move';
     print "DRYRUN: " if $self->{dry_run};
     print "$action " . join(" -> ",
         map {"`$_`"} $old, @{ $item->{intermediates} // []}, $new)."\n"
@@ -477,7 +479,10 @@ sub process_item {
         }
 
         my $err = "";
-        if ($action eq 'rename') {
+        if ($action eq 'move') {
+            $res = File::Copy::move($old, $new);
+            $err = $! unless $res;
+        } elsif ($action eq 'rename') {
             $res = rename $old, $new;
             $err = $! unless $res;
         } elsif ($action eq 'copy') {
@@ -535,8 +540,9 @@ sub rename {
     $self->{'compiled'}++;
 }
 
-
 1;
+# ABSTRACT: Module that implements perlmv
+
 
 __END__
 =pod
@@ -547,18 +553,9 @@ App::perlmv - Rename files using Perl code
 
 =head1 VERSION
 
-version 0.43
+version 0.44
 
-=head1 DESCRIPTION
-
-This application is used via the B<perlmv> command. See L<perlmv> for more
-documentation.
-
-=for Pod::Coverage .+
-
-=head1 SEE ALSO
-
-L<perlmv>
+=for Pod::Coverage ^(.*)$
 
 =head1 AUTHOR
 
@@ -566,7 +563,7 @@ Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2013 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
